Attribute VB_Name = "modFlashWindowEx"
Option Compare Database
Option Explicit

' Module copyright 2024 by Philipp Stiefel (https://codekabinett.com/en)
' You are free to use this module without restrictions as long as this copyright notice remains in place

Private Const FLASHW_ALL As Long = &H3          ' Flash both the window caption and taskbar button. This is equivalent to setting the FLASHW_CAPTION | FLASHW_TRAY flags.
Private Const FLASHW_CAPTION  As Long = &H1     ' Flash the window caption.
Private Const FLASHW_STOP  As Long = &H0        ' Stop flashing. The system restores the window to its original state.
Private Const FLASHW_TIMER As Long = &H4        ' Flash continuously, until the FLASHW_STOP flag is set.
Private Const FLASHW_TIMERNOFG   As Long = &HC  ' Flash continuously until the window comes to the foreground.
Private Const FLASHW_TRAY  As Long = &H2        ' Flash the taskbar button.

Private Type FLASHWINFO
    cbSize      As Long ' The size of the structure, in bytes.
    hwnd        As LongPtr  ' A handle to the window to be flashed. The window can be either opened or minimized.
    dwFlags     As Long ' The flash status. This parameter can be one or more of the FLASHW_ constants declared above
    uCount      As Long ' The number of times to flash the window.
    dwTimeout   As Long ' The rate at which the window is to be flashed, in milliseconds. If dwTimeout is zero, the function uses the default caret blink rate.
End Type

Private Declare PtrSafe Function FlashWindowEx Lib "User32.dll" (ByRef pfwi As FLASHWINFO) As Boolean

Public Sub FlashWindow(ByVal hwnd As LongPtr)

    Dim flashInfo As FLASHWINFO
    With flashInfo
        .hwnd = hwnd
        .dwTimeout = 500
        .uCount = 10
        .dwFlags = FLASHW_CAPTION Or FLASHW_TRAY ' Equivalent to FLASHW_ALL, combination used for demonstration purposes
        .cbSize = LenB(flashInfo)
    End With

    Call FlashWindowEx(flashInfo)

End Sub
